#
# spec file for package cdogs-sdl
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cdogs-sdl
Version:        0.10.2
Release:        bp155.2.11
Summary:        Classic overhead run-and-gun game
License:        GPL-2.0-only AND BSD-2-Clause AND CC-BY-3.0 AND CC-BY-SA-3.0
Group:          Amusements/Games/Action/Shoot
URL:            https://cxong.github.io/cdogs-sdl
Source:         https://github.com/cxong/cdogs-sdl/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 3.12
BuildRequires:  enet-devel
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  python3-protobuf
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(physfs)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(sdl2)

%description
C-Dogs SDL is a classic overhead run-and-gun game, supporting up to
4 players in co-op and deathmatch modes. Customize your player, choose
from up to 11 weapons, and try over 100 user-created campaigns. Have fun!

%prep
%setup -q
# use system enet
rm -rf src/cdogs/enet

%build
%cmake -DCDOGS_DATA_DIR=%{_datadir}/%{name}/ -DUSE_SHARED_ENET=ON
%cmake_build

%install
%cmake_install
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc README.md
%{_datadir}/applications/*.desktop
%{_bindir}/%{name}*
%{_datadir}/%{name}/
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/metainfo/*.appdata.xml

%changelog
* Tue Jan  5 2021 Martin Hauke <mardnh@gmx.de>
- Update to 0.10.2:
  * Fix loading classic campaigns
  * Fix PVP rounds not ending
  * Fix missing mouse cursor and trail
  * Fix linux build
  * Fix dogfight scores not updated properly
  * Add peaked cap hat
  * Add soldier body type
  * Improve weapon equip menu, show available weapons, allow gun
    swapping.
  * Improve game startup by skipping mission briefing if it is empty
- Drop not longer neede patches
  * cdogs-sdl-fix-desktop-and-appdata.patch
  * nanopb.patch
- Package license file and readme
* Tue Dec  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to 0.10.1:
  * Fix freeze when slow moving bullets wall bounce.
* Fri Nov 27 2020 Martin Hauke <mardnh@gmx.de>
- Update to 0.10.0:
  * Fix weapon pickup issues.
  * Fix various trailer and hitscan issues.
  * Fix crash when saving new player template.
  * Fix black "(End)" menu item in player name menu.
  * Fix bullet trail color.
  * Fix crash when co-op AI present in mission with show map
    pickup.
  * Add dog character.
  * Add option for missions having no exit area.
  * Add multiple body types in various campaigns.
  * Add facial expressions when using melee weapon, getting hurt.
* Thu Oct  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to 0.9.1:
  * Fix bugs that spawn player in locked rooms
  Game
  * Fix spawning player in locked rooms.
  * Fix spawning keys inside locked doors.
  * Add show map powerup in Doom campaign.
  Editor
  * Add color highlights for locked rooms.
  Other
  * Fix linker issue in gcc10 (fixed by @susnux).
- Drop patch:
  * cdogs-gLog.patch (fixed upstream)
* Wed Sep 30 2020 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.9.0:
  * Feature complete Doom campaign
  Game
  * Add feet colors
  * Add new hairs/hats: helmet, donut, hazmat
  * Add AI wake sounds #651
  * Fix sound spam at start of maps #605
  * Improve weapon selection by disabling menus if there are none available #628
  * Improve pause menu with background overlay #283
  Editor
  * Add level warp, multiple exits #451
  * Add static pickups #644
  * Add player template editing in editor #495
  * Add option to skip weapon selection screen #647
  * Add option for keeping picked up guns across missions #573
  * Add option for ammo persistence #350
  * Fix numpad insert/delete in editor #353
- Added nanopb.patch from nanopb upstream
- Added cdogs-gLog.patch to fix build with new gcc
- Rebased cdogs-sdl-fix-desktop-and-appdata.patch
- Spec cleanup
* Mon May 25 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.0
  * Custom tile classes and revamped Doom campaign
  Game
  * Fix string overflow for long weapon descriptions
  * Fix players sometimes spawning in locked rooms
  * Fix missing death animation
  * Fix leg animation when stationary shooting
  * Fix some bullet colors
  * Add button labels for PS3/PS4 controllers
  * Improve Doom campaign with multiple tile types, walk-through
    walls
  Editor
  * Fix background clearing
  * Add support for custom tile types for static maps
  * Add hair editing in char editor
  * Add native file open/save dialogs
  * Add support for drag/dropping guide image
  * Add hardware cursors
  * Improve guide image rendering speed
* Sun Jan  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.7.3
  Editor
  * Fix previews in character editor
  * Fix crash when changing colors
  * Add crosshairs when drag-scrolling
- Update patch:
  * cdogs-sdl-fix-desktop-and-appdata.patch
* Sat Dec 21 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.7.2
  Fix editor
  * Remove broken second window option
  * Fix editor
  * Fix mission end scores infinite incrementing
  * Fix bullet hole rendering on doors
  * Add fullscreen switching via Alt+Enter shortcut
- Add patch:
  * cdogs-sdl-fix-desktop-and-appdata.patch
* Sat Nov 23 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.7.1
  * Fix quickplay campaigns being auto saved
  * Fix broken animated score counter in debrief if score was
    negative
  * Fix red doors drawn as grey doors
  * Fix ammo count drawn under ammo gauge
  * Fix gun pickups visible even when out of sigh
  * Fix spall particles excessive speed when hit by fast bullets
  * Fix enemies dropping detonator weapon in AI Insurgency II
  * Fix NPC chatter visible even when out of sight
  * Fix NPC chatter frequency config
  * Fix NPC chatter visible in menu backgrounds
  * Fix map drawn outside automap area
  * Improve sprites with palette recoloring
* Fri Nov  1 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.7.0
  Release highlights since 0.6.7:
  * New GUI and Special Effects
  * Hitscan trails and Superhot(tm) mode
  * Full screen fixes and gun swapping
- Drop not longer needed patch:
  * cdogs-sdl-buildfix.patch
* Mon Jun 18 2018 mardnh@gmx.de
- Update to version 0.6.7
  * Add secondary weapon system (#33)
  * Add diagonal direction stickiness (#457)
  * Add option to remove blood (#544)
  * Fix unpausing not ignoring first key press (#548)
  * Fix compass arrows in shared camera view (#530)
  * Improve some sprites with semi-transparency
- Add patch:
  * cdogs-sdl-buildfix.patch
* Thu Nov  2 2017 mailaender@opensuse.org
- update to version 0.6.6 (New campaigns and HUD improvements)
  * New campaign, Grave Intent
  * New campaign, AI Insurgency 2
  * Update Sand campaign, new weapons
  * Update Doom campaign, new map items
  * Fix AI line-of-sight algorithm (#227)
  * Fix logging colours in Linux (#523)
  * Fix blood splatter speed (#489)
  * Fix audio panning (#507)
  * Fix recording high scores for co-op AI (#386)
  * Fix loading static wrecks in some older campaigns
  * Add new character heads - evil ogre, bones, big bones
  * Add second window (#383)
  * Add floating text for pickups (#380)
  * Add low ammo notifications (#362)
  * Add QWERTY layout name entry (#517)
  * Improve spectator HUD, show HUD (#382)
  * Improve health gauge, add animations (#360)
  * Improve co-op AI by avoiding friendly lines of fire (#295)
  * Fix copy pasting static levels (#525)
  * Fix incorrect objective counts when adding static objectives (#527)
  * Fix rescue/kill objectives not using access flags
  * Improve cave map type, add rooms, squares
- drop system-enet.patch (included upstream)
* Mon Jun  5 2017 mailaender@opensuse.org
- update to version 0.6.5
  * Add Harmful Crysalis campaign
  * Add hitscan weapons, continuous collision detection (#372)
  * Add scream sounds for females and other races (#371)
  * Add sound effect for opening/closing map (#468)
  * Add random seed to game start options
  * Fix editor crash on startup (#488)
  * Fix destroyed map objects dropping unavailable weapons (#493)
  * Fix missing custom hitsounds
  * Fix console window shown in Windows (#229)
  * Improve character editor (#462)
  * Improve Doom campaign with gun spawners, chainsaw, hitscan weapons
  * Add pickups from destroyed map objects (#367)
  * Add gas leak sound effect
  * Add pitch variations to some sound effects (#369)
  * Add some animated map objects to AI Insurgency campaign
  * Fix mission time not synced over network (#405)
  * Improve walk animation (#18)
  * Change command line option to allow arbitrary config settings (#473)
- drop upstreamed datadir.patch install-prefix.patch copying.patch
- drop cdogs-sdl-0.6.1-mga-unbundle-yajl.patch as lib is customized
- replace cdogs-sdl-0.6.0-mga-unbundle-enet.patch with system-enet.patch
* Fri Nov 18 2016 mailaender@opensuse.org
- update to version 0.6.3
  * Add new character faces (#69)
  * Add new character color keys (#441, #61)
  * Add Temple of Carnage dogfight map
  * Add bullet mass attribute (#444)
  * Add animated map objects (#430)
  * Add option to turn off brass shells (#448)
  * Add highlights for gun pickups
  * Add --nohud
  * Add Splitscreen AI config
  * Add extra logging around gun pickups
  * Fix showing map when paused (#446)
  * Fix various bugs around split screen logic
  * Fix obsolete valid graphics mode check (#449)
  * Fix gun recoil animations
- remove patches applied by upstream
  * cmake-install.patch
  * appdata.patch
- add copying.patch to fix FSF address etc.
- add datadir.patch and install-prefix.patch to fix the installer
* Sat Aug 20 2016 mailaender@opensuse.org
- initial packaging of version 0.6.2
